summaryrefslogtreecommitdiff
path: root/src/libcamera/media_object.cpp
diff options
context:
space:
mode:
authorJacopo Mondi <jacopo@jmondi.org>2019-01-21 17:53:28 +0100
committerJacopo Mondi <jacopo@jmondi.org>2019-01-22 14:14:04 +0100
commit1af83ca6df779fc3c7f8f4fc48f3ca82d824987d (patch)
tree7f5530f4ea838b04f23a07bb40c371c2f65e586a /src/libcamera/media_object.cpp
parentd18d25bde3064a537d4b080488941fffd61e1739 (diff)
libcamera: Global s/devnode/deviceNode rename
Do not use the abreviated version for members, variables and getter methods. Library-wise rename, no intended functional changes. Reviewed-by: Niklas Söderlund <niklas.soderlund@ragnatech.se> Reviewed-by: Laurent Pinchart <laurent.pinchart@ideasonboard.com> Signed-off-by: Jacopo Mondi <jacopo@jmondi.org>
Diffstat (limited to 'src/libcamera/media_object.cpp')
-rw-r--r--src/libcamera/media_object.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/libcamera/media_object.cpp b/src/libcamera/media_object.cpp
index a8d92e5f..baf9aeaa 100644
--- a/src/libcamera/media_object.cpp
+++ b/src/libcamera/media_object.cpp
@@ -246,7 +246,7 @@ void MediaPad::addLink(MediaLink *link)
*
* In addition to their graph id, media graph entities are identified by a
* name() unique in the media device context. They implement a function() and
- * may expose a devnode().
+ * may expose a deviceNode().
*/
/**
@@ -266,7 +266,7 @@ void MediaPad::addLink(MediaLink *link)
*/
/**
- * \fn MediaEntity::devnode()
+ * \fn MediaEntity::deviceNode()
* \brief Retrieve the entity's device node path, if any
*
* \sa int setDeviceNode()
@@ -326,23 +326,23 @@ const MediaPad *MediaEntity::getPadById(unsigned int id) const
/**
* \brief Set the path to the device node for the associated interface
* \param devnode The interface device node path associated with this entity
* \return 0 on success, or a negative error code if the device node can't be
* accessed
*/
-int MediaEntity::setDeviceNode(const std::string &devnode)
+int MediaEntity::setDeviceNode(const std::string &deviceNode)
{
/* Make sure the device node can be accessed. */
- int ret = ::access(devnode.c_str(), R_OK | W_OK);
+ int ret = ::access(deviceNode.c_str(), R_OK | W_OK);
if (ret < 0) {
ret = -errno;
LOG(MediaDevice, Error)
- << "Device node " << devnode << " can't be accessed: "
+ << "Device node " << deviceNode << " can't be accessed: "
<< strerror(-ret);
return ret;
}
- devnode_ = devnode;
+ deviceNode_ = deviceNode;
return 0;
}
@@ -326,23 +326,23 @@ const MediaPad *MediaEntity::getPadById(unsigned int id) const
/**
* \brief Set the path to the device node for the associated interface
- * \param devnode The interface device node path associated with this entity
+ * \param deviceNode The interface device node path associated with this entity
* \return 0 on success, or a negative error code if the device node can't be
* accessed